from setuptools import setup

setup(name='probability_dsnd_Udacity0303',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['probability_dsnd_Udacity0303'],
      author = 'James Bernard Jr',
      author_email = 'j_bernard0303@yahoo.com',
      zip_safe=False)